% This is a script for the integration of the
% Euler equation of motion of a symmetric heavy rigid body
% with a fixed point on the symmetry axis.

% Physical parameters, taken from
% http://rotations.berkeley.edu/the-lagrange-top/
m = 8/1000;                     %  kg
g = 9.81;                       %  m/s^2
r = 20/1000;                    %  m
I1 = 1/4*m*r^2;            %  kg-m^2
I3 = 1/2*m*r^2;            %  kg-m^2
L3 = 20/1000;                   %  m
% Position of the center of mass in the comoving frame
c_mass=[0 0 L3];

% Initial values for the ODE
ome1_0 = 1;             %  rad/s
ome2_0 = 0;             %  rad/s
ome3_0 = 1;             %  rad/s
psi0 = 0;              %  rad
theta0 = 1;           %  rad
phi0 = 0;              %  rad
u1_0 = 1/sqrt(2);
u2_0 = 0.0;
u3_0 = 1/sqrt(2);

% define the principal moments of inertia
global inertia=[I1,I1,I3];

% define the time grid
t1=(0:0.01:3.14);

% define the equation of motion
re=@(ome_ang,t) rhs_lagrange_tot(ome_ang,t,inertia,c_mass,m,g);

% Integration of the equation of motion
ome_ang0=[ome1_0,ome2_0,ome3_0,psi0,theta0,phi0,u1_0,u2_0,u3_0];
ome_ang1=lsode(re,ome_ang0,t1);
% Remark: it is possible to give initial values of the derivatives of the
% Euler angles, and then find the corresponding values of the
% angular velocities.

% Extract the components of the angular velocity and the Euler angles
o1=ome_ang1(:,1);
o2=ome_ang1(:,2);
o3=ome_ang1(:,3);
psi=ome_ang1(:,4);
theta=ome_ang1(:,5);
phi=ome_ang1(:,6);

% Initialize the moving frame
e1 = zeros(3,length(psi));
e2 = zeros(3,length(psi));
e3 = zeros(3,length(psi));

% Compute the comoving frame
for i = 1:length(psi)
    p = psi(i);
    t = theta(i);
    f = phi(i);
    rot = [cos(p)*cos(f)-sin(p)*cos(t)*sin(f)...
	   -sin(f)*cos(p)-cos(f)*sin(p)*cos(t)...
	   sin(t)*sin(p);
	   sin(p)*cos(f)+cos(p)*cos(t)*sin(f)...
	   -sin(f)*sin(p)+cos(f)*cos(p)*cos(t)...
	   -sin(t)*cos(p);
	   sin(t)*sin(f) cos(f)*sin(t) cos(t)];
    e1(:,i) = rot(:,1);
    e2(:,i) = rot(:,2);
    e3(:,i) = rot(:,3);
end

% Plot the comoving frame by plotting the vectors' tips on the unit sphere

% Initializes a figure
figure;
% Set the background color and the title on the window bar of the figure
set(gcf, 'color', 'w', 'name', 'Evolution of the comoving frame');

% Draw a transparent sphere
[X, Y, Z] = sphere;
sphere_pic = surf(X, Y, Z);
% Transparency is still not implemented in Octave!
set(sphere_pic, 'FaceAlpha', 0.1, 'EdgeAlpha', 1);

% Title of the figure and labels
title({'Trajectories of the comoving frame on the unit sphere:';...
  'e_1 = blue, e_2 = red, e_3 = black'});
xlabel('\bfe\rm_1');
ylabel('\bfe\rm_2');
zlabel('\bfe\rm_3  ', 'rotation', 0);
axis equal;
hold on;

% Draw the initial position of the comoving frame
e1v = quiver3(0,0,0, e1(1,1), e1(2,1), e1(3,1),...
	      'b', 'LineWidth', 2, 'AutoScale', 'off');
e2v = quiver3(0,0,0, e2(1,1), e2(2,1), e2(3,1),...
	      'r', 'LineWidth', 2, 'AutoScale', 'off');
e3v = quiver3(0,0,0, e3(1,1), e3(2,1), e3(3,1),...
	      'k', 'LineWidth', 2, 'AutoScale', 'off');

% Draw the trajectories of the tips of the comoving frame:
e1p = line(e1(1,:), e1(2,:), e1(3,:), 'Color', 'b', 'LineWidth', 1.5);
e2p = line(e2(1,:), e2(2,:), e2(3,:), 'Color', 'r', 'LineWidth', 1.5);
e3p = line(e3(1,:), e3(2,:), e3(3,:), 'Color', 'k', 'LineWidth', 1.5);
















